==> spirit_hub-0.1.1.22.tar.gz: spirit_hub-0.1.1.22/spec/models/docs_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(Doc, type: :model) do
  before do
    SpiritHub::HubdocCycle.import_cycle_from_json
  end

  describe 'update_tagset_doc_doc_fields' do
    let!(:tagset) { create(:tagset_doc, :with_file) }
    let!(:doc) { tagset.doc }

    it 'updates tagset doc fields' do
      expect(tagset.reload.file_ext).to eq(doc.file_ext)
      expect(tagset.reload.doc_file_size).to eq(doc.file_size)

      doc.update(file_ext: 'jpeg', file_size: 1000)

      expect(tagset.reload.file_ext).to eq('jpeg')
      expect(tagset.reload.doc_file_size).to eq(1000)
    end
  end

  describe 'generate_preview_turbo_stream' do
    let!(:doc) { create(:doc) }

    it 'broadcasts replace to doc viewer when a pdf file changes' do
      expect(doc).to receive(:broadcast_replace_to).with(
        "doc_viewer_#{doc.id}",
        target: "doc_viewer_#{doc.id}",
        partial: 'spirit_hub/common/doc_viewer_content',
        locals: { doc:, doc_download_url: doc.doc_download_url }
      )

      doc.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/one_page.pdf'))
    end

    it 'broadcasts replace to doc viewer when page_urls changes' do
      expect(doc).to receive(:broadcast_replace_to).with(
        "doc_viewer_#{doc.id}",
        target: "doc_viewer_#{doc.id}",
        partial: 'spirit_hub/common/doc_viewer_content',
        locals: { doc:, doc_download_url: doc.doc_download_url }
      )

      doc.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/dog.jpg'))
      doc.generate_preview
    end

    it 'does not broadcast replace to doc viewer' do
      expect(doc).not_to receive(:broadcast_replace_to)

      doc.update(title: 'New title')
    end
  end
end

==> spirit_hub-0.1.1.36.tar.gz: spirit_hub-0.1.1.36/spec/models/docs_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(Doc, type: :model) do
  before do
    SpiritHub::HubdocCycle.import_cycle_from_json
  end

  describe 'update_tagset_doc_doc_fields' do
    let!(:tagset) { create(:tagset_doc, :with_file) }
    let!(:doc) { tagset.doc }

    it 'updates tagset doc fields' do
      expect(tagset.reload.file_ext).to eq(doc.file_ext)
      expect(tagset.reload.doc_file_size).to eq(doc.file_size)

      doc.update(file_ext: 'jpeg', file_size: 1000)

      expect(tagset.reload.file_ext).to eq('jpeg')
      expect(tagset.reload.doc_file_size).to eq(1000)
    end
  end

  describe 'generate_preview_turbo_stream' do
    let!(:doc) { create(:doc) }

    it 'broadcasts replace to doc viewer when a pdf file changes' do
      expect(doc).to receive(:broadcast_replace_to).with(
        "doc_viewer_#{doc.id}",
        target: "doc_viewer_#{doc.id}",
        partial: 'spirit_hub/common/doc/doc_viewer_content',
        locals: { doc:, doc_download_url: doc.doc_download_url }
      )

      doc.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/one_page.pdf'))
    end

    it 'broadcasts replace to doc viewer when page_urls changes' do
      expect(doc).to receive(:broadcast_replace_to).with(
        "doc_viewer_#{doc.id}",
        target: "doc_viewer_#{doc.id}",
        partial: 'spirit_hub/common/doc/doc_viewer_content',
        locals: { doc:, doc_download_url: doc.doc_download_url }
      )

      doc.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/dog.jpg'))
      doc.generate_preview
    end

    it 'does not broadcast replace to doc viewer' do
      expect(doc).not_to receive(:broadcast_replace_to)

      doc.update(title: 'New title')
    end
  end
end
